@@ -1,4 +1,8 @@
-create_corpus <- function(matrix,labels,trainSize,testSize,virgin) {
+create_corpus <- function(matrix,labels,trainSize=NULL,testSize=NULL,virgin) {
+	if (is.null(trainSize) && is.null(testSize)) stop("You must specify either a trainSize or testSize parameter, or both.")
+	if (is.null(trainSize)) trainSize <- testSize
+	if (is.null(testSize)) testSize <- trainSize
+
 	totalSize <- sort(unique(append(trainSize,testSize)))
 	column_names <- colnames(matrix)
 	data_matrix <- as.compressed.matrix(matrix[totalSize])
